@@ -5,7 +5,6 @@ use HTTP::Engine::Interface
         response_line => 1,
     }
 ;
-use HTTP::Engine::ClassCreator;
 
 use HTTP::Server::Simple 0.34;
 use HTTP::Server::Simple::CGI;
@@ -31,21 +30,22 @@ has net_server => (
 sub run {
     my ($self, ) = @_;
 
-    my $headers = HTTP::Headers::Fast->new;
+    my $headers;
     my %setup;
     my $server;
-    $server = HTTP::Engine::ClassCreator
-        ->create_anon(
+    $server = Mouse::Meta::Class
+        ->create_anon_class(
             superclasses => ['HTTP::Server::Simple'],
             methods => {
-                headers => sub {
-                    my ( $self, $args ) = @_;
-                    $headers->header(@$args);
-                },
                 setup => sub {
                     shift; # $self;
+                    $headers = HTTP::Headers::Fast->new;
                     %setup = @_;
                 },
+                headers => sub {
+                    my ( $self, $args ) = @_;
+                    $headers->header(@$args) if @$args;
+                },
                 handler    => sub {
                     my($host, $port) = $headers->header('Host') ?
                         split(':', $headers->header('Host')) :($setup{localname}, $setup{localport});
@@ -79,7 +79,7 @@ sub run {
                 net_server => sub { $self->net_server },
             },
             cache => 1
-        )->new(
+        )->name->new(
             $self->port
         );
     $server->host($self->host);
